.. currentmodule:: sardana.tango.core

:mod:`~sardana.tango.core`
============================

.. automodule:: sardana.tango.core

.. rubric:: Modules

.. toctree::
    :maxdepth: 1
    
    SardanaDevice <core/SardanaDevice>

